@@ -79,7 +79,7 @@ Note that concentrations are uncorrelated between different site (even of the sa
         None,
         description="""Can be any valid Unicode string, and SHOULD contain (if specified) the name of the species that is used internally in the source database.
 
-Note: With regards to "source database", we refer to the immediate source being queried via the OPTiMaDe API implementation.
+Note: With regards to "source database", we refer to the immediate source being queried via the OPTIMADE API implementation.
 The main use of this field is for source databases that use species names, containing characters that are not allowed (see description of the list property `species_at_sites`_).""",
     )
 
@@ -374,7 +374,7 @@ class StructureResourceAttributes(EntryResourceAttributes):
   - If a component of the position is unknown, the :val:`null` value should be provided instead (see section `Properties with unknown value`_).
     Otherwise, it should be a float value, expressed in angstrom (Å).
     If at least one of the coordinates is unknown, the correct flag in the list property `structure_features`_ MUST be set.
-  - **Notes**: (for implementers) While this is unrelated to this OPTiMaDe specification: If you decide to store internally the :property: `cartesian_site_positions` as a float array, you might want to represent :val:`null` values with :field-val:`NaN` values.
+  - **Notes**: (for implementers) While this is unrelated to this OPTIMADE specification: If you decide to store internally the :property: `cartesian_site_positions` as a float array, you might want to represent :val:`null` values with :field-val:`NaN` values.
     The latter being valid float numbers in the IEEE 754 standard in `IEEE 754-1985 <https://doi.org/10.1109/IEEESTD.1985.82928>`__ and in the updated version `IEEE 754-2008 <https://doi.org/10.1109/IEEESTD.2008.4610935>`__.
 
 - **Examples**:
@@ -464,7 +464,7 @@ class StructureResourceAttributes(EntryResourceAttributes):
     - **mass**: OPTIONAL. If present MUST be a float expressed in a.m.u.
     - **original_name**: OPTIONAL. Can be any valid Unicode string, and SHOULD contain (if specified) the name of the species that is used internally in the source database.
 
-        Note: With regards to "source database", we refer to the immediate source being queried via the OPTiMaDe API implementation.
+        Note: With regards to "source database", we refer to the immediate source being queried via the OPTIMADE API implementation.
             The main use of this field is for source databases that use species names, containing characters that are not allowed (see description of the list property `species_at_sites`_).
 
   - For systems that have only species formed by a single chemical symbol, and that have at most one species per chemical symbol, SHOULD use the chemical symbol as species name (e.g., :val:`"Ti"` for titanium, :val:`"O"` for oxygen, etc.)
@@ -641,20 +641,33 @@ class StructureResourceAttributes(EntryResourceAttributes):
 
     @validator("lattice_vectors", always=True)
     def required_if_dimension_types_has_one(cls, v, values):
-        if 1 in values.get("dimension_types", []) and v is None:
+        if (
+            Periodicity.PERIODIC.value in values.get("dimension_types", [])
+            and v is None
+        ):
             raise ValueError(
-                f"lattice_vectors is REQUIRED, since dimension_types is not [0, 0, 0] but is {values.get('dimension_types', 'Not specified')}"
+                f"lattice_vectors is REQUIRED, since dimension_types is not ({(Periodicity.APERIODIC.value,) * 3}) but is "
+                f"{tuple(getattr(_, 'value', None) for _ in values.get('dimension_types', []))}"
             )
 
-        for dim_type, vector in zip(values.get("dimension_types", []), v):
-            if None in vector and dim_type == 1:
+        for dim_type, vector in zip(values.get("dimension_types", (None,) * 3), v):
+            if None in vector and dim_type == Periodicity.PERIODIC.value:
                 raise ValueError(
-                    "Null entries in lattice vectors are only permitted when the corresponding dimension type is 0. "
-                    f"Here: dimension_types = {values.get('dimension_types', 'Not specified')}, lattice_vectors = {v}"
+                    f"Null entries in lattice vectors are only permitted when the corresponding dimension type is {Periodicity.APERIODIC.value}. "
+                    f"Here: dimension_types = {tuple(getattr(_, 'value', None) for _ in values.get('dimension_types', []))}, lattice_vectors = {v}"
                 )
 
         return v
 
+    @validator("lattice_vectors")
+    def null_values_for_whole_vector(cls, v):
+        for vector in v:
+            if None in vector and any((isinstance(_, float) for _ in vector)):
+                raise ValueError(
+                    f"A lattice vector MUST be either all `null` or all numbers (vector: {vector}, all vectors: {v})"
+                )
+        return v
+
     @validator("nsites")
     def validate_nsites(cls, v, values):
         if v != len(values.get("cartesian_site_positions", [])):
