@@ -1,7 +1,5 @@
 # pylint: disable=line-too-long
-import os
 import json
-from pathlib import Path
 
 from lark.exceptions import VisitError
 
@@ -24,9 +22,9 @@ if CONFIG.debug:  # pragma: no cover
 
 
 app = FastAPI(
-    title="OPTiMaDe API - Index meta-database",
+    title="OPTIMADE API - Index meta-database",
     description=(
-        f"""The [Open Databases Integration for Materials Design (OPTiMaDe) consortium](https://www.optimade.org/) aims to make materials databases interoperational by developing a common REST API.
+        f"""The [Open Databases Integration for Materials Design (OPTIMADE) consortium](https://www.optimade.org/) aims to make materials databases interoperational by developing a common REST API.
 This is the "special" index meta-database.
 
 This specification is generated using [`optimade-python-tools`](https://github.com/Materials-Consortia/optimade-python-tools/tree/v{__version__}) v{__version__}."""
@@ -92,18 +90,7 @@ def add_optional_versioned_base_urls(app: FastAPI):
         app.include_router(links.router, prefix=BASE_URL_PREFIXES[version])
 
 
-def update_schema(app: FastAPI):
-    """Update OpenAPI schema in file 'local_index_openapi.json'"""
-    package_root = Path(__file__).parent.parent.parent.resolve()
-    if not package_root.joinpath("openapi").exists():
-        os.mkdir(package_root.joinpath("openapi"))
-    with open(package_root.joinpath("openapi/local_index_openapi.json"), "w") as f:
-        json.dump(app.openapi(), f, indent=2)
-
-
 @app.on_event("startup")
 async def startup_event():
-    # Update OpenAPI schema on versioned base URL `/vMAJOR`
-    update_schema(app)
     # Add API endpoints for OPTIONAL base URLs `/vMAJOR.MINOR` and `/vMAJOR.MINOR.PATCH`
     add_optional_versioned_base_urls(app)
