@@ -10,6 +10,7 @@ from optimade.models import (
     IndexInfoAttributes,
     IndexInfoResource,
     IndexRelationship,
+    RelatedLinksResource,
 )
 
 from optimade.server.config import CONFIG
@@ -36,7 +37,7 @@ def get_info(request: Request):
                 api_version=f"v{__api_version__}",
                 available_api_versions=[
                     {
-                        "url": f"{CONFIG.provider['index_base_url']}/v{__api_version__.split('.')[0]}/",
+                        "url": f"{CONFIG.provider.index_base_url}/v{__api_version__.split('.')[0]}/",
                         "version": f"{__api_version__}",
                     }
                 ],
@@ -47,7 +48,12 @@ def get_info(request: Request):
             ),
             relationships={
                 "default": IndexRelationship(
-                    data={"type": "child", "id": CONFIG.default_db}
+                    data={
+                        "type": RelatedLinksResource.schema()["properties"]["type"][
+                            "const"
+                        ],
+                        "id": CONFIG.default_db,
+                    }
                 )
             },
         ),
