@@ -43,7 +43,7 @@ def meta_values(
     **kwargs,
 ) -> ResponseMeta:
     """Helper to initialize the meta values"""
-    from optimade.models import ResponseMetaQuery, Provider, Implementation
+    from optimade.models import ResponseMetaQuery
 
     parse_result = urllib.parse.urlparse(url)
 
@@ -56,7 +56,7 @@ def meta_values(
     return ResponseMeta(
         query=ResponseMetaQuery(representation=f"{url_path}?{parse_result.query}"),
         api_version=f"v{__api_version__}",
-        time_stamp=datetime.utcnow(),
+        time_stamp=datetime.now(),
         data_returned=data_returned,
         more_data_available=more_data_available,
         provider=CONFIG.provider,
@@ -282,6 +282,9 @@ def retrieve_queryable_properties(schema: dict, queryable_properties: list) -> d
                 properties[name] = {"description": value.get("description", "")}
                 if "unit" in value:
                     properties[name]["unit"] = value["unit"]
+                # All properties are sortable with the MongoDB backend.
+                # While the result for sorting lists may not be as expected, they are still sorted.
+                properties[name]["sortable"] = True
     return properties
 
 
